/* Reseni ulohy Koleje v C++

   Jan Kybic, kybic@fel.cvut.cz
*/

#include <iostream>
#include <math.h>
#include <set>
#include <list>
#include <vector>
#include <queue>
#include <utility>
#include <limits>

using namespace std ;

// #define DEBUG

const double eps=1e-6 ;
const double infinity = numeric_limits<double>::infinity() ;

struct Coord {
  double x,y ; // the coordinates
  // neighbors and whether we have taken that edge
  list<pair<Coord*,bool> > nbrs ; 

  void add_nbr(Coord* x) {
    nbrs.push_back(make_pair(x,false)) ;
  } ;
 
  Coord(double xin, double yin) : x(xin), y(yin) {
  } ;
} ;

double distance(Coord *a,Coord *b) {
  double dx = a->x - b->x ;
  double dy = a->y - b->y ;
  return sqrt ( dx*dx + dy*dy ) ;
}

bool can_turn(double dx1,double dy1, double dx2, double dy2) {
  return dx1*dx2+dy1*dy2>=-eps ;
} 

struct CoordComp {
  bool operator()(Coord* one, Coord* other) const {
    double d = one->x - other->x ;
    if (d < -eps) return true ;
    if ( d > eps ) return false ;
    if (one->y - other->y < -eps) return true ;
    return false ;
  } ;
} ;

ostream& operator<< (ostream& out,const Coord& c) {
  out << "(" << c.x << "," << c.y << ")" ;
  return out ;
}

struct Step {
  // used during the search phase
  Coord* cur ;
  double dx,dy ; // increment of the last leg
  double dist ; // distance from the starting point
  Step(Coord *c,double x, double y,double d) : cur(c), dx(x), dy(y), dist(d) {} ;
} ;

struct StepComp {
  bool operator()(Step& one, Step& two) const {
    return one.dist > two.dist  ;
  } ;
} ;



struct Edge {
  Coord& p ;
  Coord& q ; 
  bool firstflag,lastflag ;
  bool skip ;

  Edge(Coord& pi,Coord& qi) : p(pi), q(qi), firstflag(false),
                              lastflag(false), skip(false) { } ;

} ;

ostream& operator<< (ostream& out,const Edge& e) {
    out << "[" << e.p << "-" << e.q << "]" ;
    return out ;
}


class Intersection {
    double x,y,s,t ;
  public:
    Intersection(Edge e1,Edge e2) {
      double a=e1.q.x - e1.p.x ;
      double b=e2.p.x-e2.q.x ;
      double c=e1.q.y - e1.p.y ;
      double d=e2.p.y-e2.q.y ;
      double e=e2.p.x-e1.p.x ;
      double f=e2.p.y-e1.p.y ;
      double det=a*d-b*c ;
      s=(e*d-b*f)/det ;
      t=(a*f-c*e)/det ;
      x=e1.p.x*(1-s)+e1.q.x*s ; 
      y=e1.p.y*(1-s)+e1.q.y*s ; 
    };

    bool intersect_s() {
      return (s>eps && s<1.-eps) ;
    };

    bool intersect_t() {
      return (t>eps && t<1.-eps) ;
    };

    bool intersect() {
      return (s>=-eps && s<=1.+eps) && (t>=-eps && t<=1.+eps) ;
    } ;

    double intersection_x() { return x ; } ;
    double intersection_y() { return y ; } ;

  } ;

class Solver {
  // we need to use both points and coords since 'set::insert' returns an
  // iterator that when dereferenced has a "const" modifier and thus
  // the members of coords cannot be modified once inserted.
  list<Coord> points ;
  set<Coord *,CoordComp> coords ;
  list<Edge> edges ;
  queue<pair<Edge,list<Edge>::iterator> > unprocessed ;

  Coord *firstpoint,*secondpoint,*beforelastpoint,*lastpoint ;

public:

  Coord& insert_point(double x, double y) {
#ifdef DEBUG
    cout << "insert_point(" << x << "," << y << ")  " ;
#endif
      Coord p((double)x,(double)y) ; 
      set<Coord *,CoordComp>::iterator it ;
      it=coords.find(&p) ;
      if (it==coords.end()) { // new point
#ifdef DEBUG
        cout << " new point.\n" ;
#endif
        points.push_back(p) ;
        coords.insert(&points.back()) ; // store a reference
        return points.back() ;
      }
      // already existing point
#ifdef DEBUG
        cout << " existing point.\n" ;
#endif
      return **it ;
  };

  void handle_crossings() {
    while (!unprocessed.empty()) {
      pair<Edge,list<Edge>::iterator> e=unprocessed.front () ;
      bool crosses=false ;
      unprocessed.pop () ;
      // e.second=edges.begin() ;
      // cout << "handle_crossing: considering e=" << e.first << "\n" ;
      while(e.second!=edges.end()) {
        // cout << "  examine intersection with " << *e.second << "\n" ;
        list<Edge>::iterator next_edge=e.second ;
        ++next_edge ;
        if (e.second->skip) { e.second=next_edge ; continue ; } // skip this edge 
        //if (next_edge==edges.end())
        //  cout << "  next element next_edge is end\n" ;
        //else
        //  cout << "  next element next_edge is " << *next_edge << "\n" ;
        Intersection ints(e.first,*e.second) ;
        if (ints.intersect()) {
          Coord& c=insert_point(ints.intersection_x(),ints.intersection_y()) ;
          // cout << "  intersecting at point c=" << c << "\n" ;
          if (ints.intersect_s()) {
            Edge e1(e.first.p,c) ;
            Edge e2(c,e.first.q) ;
            // cout << "  e is divided into e1=" << e1 << " and e2=" << e2 << "\n" ;
            // the two parts of e.first to be processed again
            if (e.first.firstflag) e1.firstflag=true ;
            if (e.first.lastflag) e2.lastflag=true ;
            unprocessed.push(make_pair(e1,next_edge)) ;
            unprocessed.push(make_pair(e2,next_edge)) ;
            crosses=true ;
          } 
          if (ints.intersect_t()) {
            // divide the edge *e.second
            Edge e3(e.second->p,c) ;
            Edge e4(c,e.second->q) ;
            // cout << "  e.second is divided into e3=" << e3 << " and e4=" << e4 << "\n" ;
            if (e.second->firstflag) e3.firstflag=true ;
            if (e.second->lastflag) e4.lastflag=true ;
            // edges.erase(e.second) ;
            e.second->skip=true ; 
            edges.push_back(e3) ;
            edges.push_back(e4) ;
          }
          if (crosses) break ;
        } 
        e.second=next_edge ;
      } // end while e.second!=edges.end
      if (e.second==edges.end()) 
        edges.push_back(e.first) ;
    } // end while
  } ;

  void build_graph() {
#ifdef DEBUG
    cout << "build_graph: \n" ;
#endif

    for (list<Edge>::iterator i=edges.begin();i!=edges.end();i++) {
      //       cout << "  edge:" << *i << "\n" ;
      if (!i->skip) {
        i->p.add_nbr(&i->q) ;
        i->q.add_nbr(&i->p) ;
        if (i->firstflag) { firstpoint=&i->p ; secondpoint=&i->q ; } ;
        if (i->lastflag) { beforelastpoint=&i->p ; lastpoint=&i->q ; } ;
      }
    }
#ifdef DEBUG
    // just for visualization
    for(list<Coord>::iterator j=points.begin();j!=points.end();j++) 
      {
        cout << "point: " << *j ;
        if (&*j==firstpoint) cout << " firstpoint " ;
        if (&*j==secondpoint) cout << " secondpoint " ;
        if (&*j==beforelastpoint) cout << " beforelastpoint " ;
        if (&*j==lastpoint) cout << " lastpoint " ;
        cout << "  nbrs: " ;
        for (list<pair<Coord *,bool> >::iterator k=j->nbrs.begin();
             k!=j->nbrs.end();k++)
          cout << *(k->first) << " " ;
        cout << "\n" ;
      } ;
#endif

  } ;




  double find_nearest_distance() {
    priority_queue<Step,vector<Step>,StepComp> q ;
    double finaldx=lastpoint->x - beforelastpoint->x ;
    double finaldy=lastpoint->y - beforelastpoint->y ;

    Step s(firstpoint,secondpoint->x - firstpoint->x,
           secondpoint->y - firstpoint->y,0.) ;
    #ifdef DEBUG
        cout << "firstpoint: " << *firstpoint 
        << " secondpoint: " << *secondpoint << "\n" ;
    #endif
    q.push(s) ;

    while (!q.empty()) {
      Step s=q.top() ;
      q.pop() ;
#ifdef DEBUG
      cout << "find nearest top = -> "
           << *(s.cur) 
           << " dx=" << s.dx << " dy=" << s.dy 
           << "  dist =" << s.dist << "\n" ;
#endif
      if (s.cur==lastpoint && can_turn(s.dx,s.dy,finaldx,finaldy)) {
#ifdef DEBUG        
              cout << "Destination reached in " << s.dist << "\n";
#endif
        return s.dist ; }
      // go over all neighbors
        for(list<pair<Coord *,bool> >::iterator i=s.cur->nbrs.begin();
            i!=s.cur->nbrs.end();i++)  {
#ifdef DEBUG
         cout << "  considering neighbor " << *(i->first) << "\n" ;
#endif
              if (!i->second) // not yet visited
                {
                  double dx = (i->first)->x-s.cur->x ;
                  double dy=  (i->first)->y-s.cur->y ;
                  //              cout <<  "  dx=" << dx << "  dy=" << dy << "\n" ;
                  if (can_turn(s.dx,s.dy,dx,dy)) {
#ifdef DEBUG
                    cout << "  turning possible.\n" ;
#endif
                    i->second=true ; // edge taken
                    double d=s.dist+distance(s.cur,i->first) ;
#ifdef DEBUG                    
                    cout << "  total distance " << d << "\n" ;
#endif
                    Step ns(i->first,dx,dy,d) ;
                    q.push(ns) ;
                  }
        } 
      }
    } 
#ifdef DEBUG
              cout << "queue is empty.\n" ;
#endif
    return infinity ;
  } ;

  double solve(int n) {
    for(int i=0;i<n;i++) {
      double x1,y1,x2,y2 ;
      cin >> x1 >> y1 >> x2 >> y2 ;
      Coord& c1=insert_point(x1,y1) ;
      Coord& c2=insert_point(x2,y2) ;
      // this is the new edge
      Edge e(c1,c2) ;
      // cout << "read new edge number " << i << ": " << e << "\n" ;
      // cout << "current edges:\n" ;
      //      for (list<Edge>::iterator j=edges.begin();j!=edges.end();j++) {
      //  cout << "  edge:" << *j << "\n" ; }
      if (i==0) e.firstflag=true ;
      if (i==n-1) e.lastflag=true ;
      unprocessed.push(make_pair(e,edges.begin())) ;
      handle_crossings() ;
    }
    build_graph() ;
    return find_nearest_distance() ;
  } ; // end of solve

} ;


int main() {
  int n ; /* number of lines */
  int i ; /* robot number */

  for(i=1;;i++) {
    cin >> n ;
    if (n==0) return 0 ; 
    Solver s ;
    double d=s.solve(n) ;
    //cout << "Robot #" << i << ": " ;
    if (d==infinity)  
        cout << "unreachable\n" ;
      else {
        cout.setf(ios::fixed,ios::floatfield);
        cout.precision(3);
        cout << d << "\n" ;
      }
  }
  return  0 ;
} 
